@@ -2,6 +2,9 @@
 App settings
 """
 
+# Standard Library
+from re import RegexFlag
+
 # Django
 from django.apps import apps
 from django.conf import settings
@@ -54,3 +57,14 @@ def discordproxy_installed() -> bool:
         return False
 
     return True
+
+
+def debug_enabled() -> RegexFlag:
+    """
+    Check if DEBUG is enabled
+
+    :return:
+    :rtype:
+    """
+
+    return settings.DEBUG
