@@ -2,23 +2,31 @@
 Constants
 """
 
-# Django
-from django.utils.text import slugify
-from django.utils.translation import gettext_lazy as _
+# Standard Library
+from enum import Enum
+
+# Third Party
+from requests.__version__ import __version__ as requests_version
 
 # AA SRP
-from aasrp import __version__
+from aasrp import __app_name_useragent__, __github_url__
+from aasrp import __version__ as app_version
 
-VERBOSE_NAME = "AA-SRP - A ship replacement module for Alliance Auth"
-
-verbose_name_slugified: str = slugify(value=VERBOSE_NAME, allow_unicode=True)
-github_url: str = "https://github.com/ppfeufer/aa-srp"
-USERAGENT = f"{verbose_name_slugified} v{__version__} {github_url}"
+# All internal URLs need to start with this prefix
+INTERNAL_URL_PREFIX = "-"
 
 
-SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE = _(
+class UserAgent(Enum):
+    """
+    UserAgent
+    """
+
+    REQUESTS = f"{__app_name_useragent__}/{app_version} (+{__github_url__}) requests/{requests_version}"
+
+
+SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE = (
     "If you have any questions regarding your SRP request, feel free to contact your "
-    "request reviser.\nPlease make sure to always add the SRP code and the "
+    "request reviser. Please make sure to always add the SRP code and the "
     "request code with your inquiry."
 )
 
@@ -43,15 +51,20 @@ KILLBOARD_DATA = {
 }
 
 
-# Embed colors
-DISCORD_EMBED_COLOR_INFO = 0x5BC0DE
-DISCORD_EMBED_COLOR_SUCCESS = 0x5CB85C
-DISCORD_EMBED_COLOR_WARNING = 0xF0AD4E
-DISCORD_EMBED_COLOR_DANGER = 0xD9534F
+class DiscordEmbedColor(Enum):
+    """
+    Discord embed colors
+    """
+
+    INFO = 0x5BC0DE
+    SUCCESS = 0x5CB85C
+    WARNING = 0xF0AD4E
+    DANGER = 0xD9534F
+
 
 DISCORD_EMBED_COLOR_MAP = {
-    "info": DISCORD_EMBED_COLOR_INFO,
-    "success": DISCORD_EMBED_COLOR_SUCCESS,
-    "warning": DISCORD_EMBED_COLOR_WARNING,
-    "danger": DISCORD_EMBED_COLOR_DANGER,
+    "info": DiscordEmbedColor.INFO.value,
+    "success": DiscordEmbedColor.SUCCESS.value,
+    "warning": DiscordEmbedColor.WARNING.value,
+    "danger": DiscordEmbedColor.DANGER.value,
 }
