@@ -12,6 +12,7 @@ from allianceauth.eveonline.models import EveCharacter
 
 # AA SRP
 from aasrp.helper.eve_images import get_character_portrait_from_evecharacter
+from aasrp.helper.icons import copy_to_clipboard_icon
 from aasrp.models import get_sentinel_user
 
 
@@ -45,7 +46,7 @@ def get_formatted_character_name(
         character_name = _("Unknown character")
 
         return (
-            "<span class='aasrp-character-portrait-character-name'>"
+            "<span class='aasrp-character-portrait-character-name d-inline-block align-middle'>"
             f"{character_name}"
             "</span>"
         )
@@ -62,34 +63,25 @@ def get_formatted_character_name(
         f"<br>{character_name}"
     )
 
-    if with_copy_icon is True:
+    if with_copy_icon:
         title = _("Copy character name to clipboard")
-        character_name_formatted += (
-            "<i "
-            'class="aa-srp-fa-icon copy-text-fa-icon fa-regular fa-copy ms-2" '
-            f'data-clipboard-text="{character_name}" title="{title}" '
-            'data-bs-tooltip="aa-srp"></i>'
-        )
-
-    return_value = character_name_formatted
-
-    if with_portrait is True:
-        line_break = ""
-        if inline is False:
-            line_break = "<br>"
+        copy_icon = copy_to_clipboard_icon(data=character_name, title=title)
+        character_name_formatted += f"<sup>{copy_icon}</sup>"
 
+    if with_portrait:
+        line_break = "<br>" if not inline else ""
         character_portrait_html = get_character_portrait_from_evecharacter(
             character=character, size=portrait_size, as_html=True
         )
 
-        return_value = (
+        return (
             f"{character_portrait_html}{line_break}"
-            "<span class='aasrp-character-portrait-character-name'>"
+            "<span class='aasrp-character-portrait-character-name d-inline-block align-middle'>"
             f"{character_name_formatted}"
             "</span>"
         )
 
-    return return_value
+    return character_name_formatted
 
 
 def get_main_for_character(character: EveCharacter) -> EveCharacter | None:
@@ -103,7 +95,7 @@ def get_main_for_character(character: EveCharacter) -> EveCharacter | None:
     """
 
     try:
-        userprofile = character.character_ownership.user.profile
+        return character.character_ownership.user.profile.main_character
     except (
         AttributeError,
         EveCharacter.character_ownership.RelatedObjectDoesNotExist,
@@ -111,8 +103,6 @@ def get_main_for_character(character: EveCharacter) -> EveCharacter | None:
     ):
         return None
 
-    return userprofile.main_character
-
 
 def get_user_for_character(character: EveCharacter) -> User:
     """
@@ -125,12 +115,10 @@ def get_user_for_character(character: EveCharacter) -> User:
     """
 
     try:
-        userprofile = character.character_ownership.user.profile
+        return character.character_ownership.user.profile.user
     except (
         AttributeError,
         EveCharacter.character_ownership.RelatedObjectDoesNotExist,
         CharacterOwnership.user.RelatedObjectDoesNotExist,
     ):
         return get_sentinel_user()
-
-    return userprofile.user
