@@ -24,6 +24,7 @@ from aasrp.helper.character import (
     get_user_for_character,
 )
 from aasrp.helper.eve_images import get_character_portrait_from_evecharacter
+from aasrp.helper.icons import copy_to_clipboard_icon
 from aasrp.models import get_sentinel_user
 
 
@@ -99,17 +100,19 @@ class TestGetFormattedCharacterName(TestCase):
         :rtype:
         """
 
+        self.maxDiff = None
+
         html = get_formatted_character_name(
             character=self.alt_character, with_copy_icon=True
         )
 
-        copy_icon = (
-            "<i "
-            'class="aa-srp-fa-icon copy-text-fa-icon fa-regular fa-copy ms-2" '
-            f'data-clipboard-text="{self.alt_character.character_name}" '
-            'title="Copy character name to clipboard" data-bs-tooltip="aa-srp"></i>'
+        icon = copy_to_clipboard_icon(
+            data=self.alt_character.character_name,
+            title="Copy character name to clipboard",
         )
 
+        copy_icon = f"<sup>{icon}</sup>"
+
         expected_html = (
             "<small class='text-muted'>"
             f"{self.alt_character.alliance_ticker} "
@@ -141,7 +144,7 @@ class TestGetFormattedCharacterName(TestCase):
 
         expected_html = (
             f"{character_portrait_html}<br>"
-            "<span class='aasrp-character-portrait-character-name'>"
+            "<span class='aasrp-character-portrait-character-name d-inline-block align-middle'>"
             f"{formatted_character_name}"
             "</span>"
         )
@@ -170,7 +173,7 @@ class TestGetFormattedCharacterName(TestCase):
 
         expected_html = (
             f"{character_portrait_html}"
-            "<span class='aasrp-character-portrait-character-name'>"
+            "<span class='aasrp-character-portrait-character-name d-inline-block align-middle'>"
             f"{formatted_character_name}"
             "</span>"
         )
@@ -189,7 +192,7 @@ class TestGetFormattedCharacterName(TestCase):
         html = get_formatted_character_name(character=None)
 
         expected_html = (
-            "<span class='aasrp-character-portrait-character-name'>"
+            "<span class='aasrp-character-portrait-character-name d-inline-block align-middle'>"
             "Unknown character"
             "</span>"
         )
