@@ -10,7 +10,6 @@ from django.test import TestCase
 from allianceauth.tests.auth_utils import AuthUtils
 
 # AA SRP
-from aasrp import __version__
 from aasrp.models import get_sentinel_user
 from aasrp.tests.utils import create_fake_user
 
@@ -189,6 +188,7 @@ class TestMainCharacterCorporationName(TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         super().setUpClass()
+
         cls.template = Template(
             template_string="{% load aasrp %}{{ user|main_character_corporation_name }}"
         )
@@ -279,6 +279,7 @@ class TestMainCorporationId(TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         super().setUpClass()
+
         cls.template = Template(
             template_string="{% load aasrp %}{{ user|main_character_corporation_id }}"
         )
@@ -369,6 +370,7 @@ class TestMainCharacterAllianceName(TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         super().setUpClass()
+
         cls.template = Template(
             template_string="{% load aasrp %}{{ user|main_character_alliance_name }}"
         )
@@ -488,6 +490,7 @@ class TestMainAllianceId(TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         super().setUpClass()
+
         cls.template = Template(
             template_string="{% load aasrp %}{{ user|main_character_alliance_id }}"
         )
@@ -596,31 +599,3 @@ class TestMainAllianceId(TestCase):
 
         # then
         self.assertEqual(first=result, second="1")
-
-
-class TestForumVersionedStatic(TestCase):
-    """
-    Tests for aasrp_static template tag
-    """
-
-    def test_versioned_static(self):
-        """
-        Test should return the static URL string with the app version
-
-        :return:
-        :rtype:
-        """
-
-        context = Context(dict_={"version": __version__})
-        template_to_render = Template(
-            template_string=(
-                "{% load aasrp %}{% aasrp_static 'aasrp/css/aa-srp.min.css' %}"
-            )
-        )
-
-        rendered_template = template_to_render.render(context=context)
-
-        self.assertInHTML(
-            needle=f'/static/aasrp/css/aa-srp.min.css?v={context["version"]}',
-            haystack=rendered_template,
-        )
