@@ -2,8 +2,11 @@
 Ajax views
 """
 
+# Standard Library
+import json
+
 # Django
-from django.contrib.auth.decorators import login_required, permission_required
+from django.contrib.auth.decorators import permission_required
 from django.core.handlers.wsgi import WSGIRequest
 from django.db.models import Q
 from django.http import HttpResponse, JsonResponse
@@ -18,12 +21,9 @@ from allianceauth.services.hooks import get_extension_logger
 # Alliance Auth (External Libs)
 from app_utils.logging import LoggerAddTag
 from app_utils.urls import reverse_absolute
-from eveuniverse.models import EveType
 
 # AA SRP
 from aasrp import __title__
-from aasrp.constants import SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE
-from aasrp.discord.direct_message import send_user_notification
 from aasrp.form import (
     SrpRequestAcceptForm,
     SrpRequestAcceptRejectedForm,
@@ -33,52 +33,26 @@ from aasrp.form import (
 from aasrp.helper.character import get_formatted_character_name
 from aasrp.helper.eve_images import get_type_render_url_from_type_id
 from aasrp.helper.icons import (
-    get_dashboard_action_icons,
+    copy_to_clipboard_icon,
+    dashboard_action_icons,
     get_srp_request_action_icons,
     get_srp_request_details_icon,
     get_srp_request_status_icon,
 )
+from aasrp.helper.notification import notify_requester
+from aasrp.helper.srp_data import (
+    attempt_to_re_add_ship_information_to_request,
+    localized_isk_value,
+    payout_amount_html,
+    request_code_html,
+    request_fleet_details_html,
+)
 from aasrp.helper.user import get_user_settings
-from aasrp.managers import SrpManager
 from aasrp.models import RequestComment, SrpLink, SrpRequest
 
 logger = LoggerAddTag(my_logger=get_extension_logger(__name__), prefix=__title__)
 
 
-def _attempt_to_re_add_ship_information_to_request(
-    srp_request: SrpRequest,
-) -> SrpRequest:
-    """
-    If for some reason the ship gets removed from EveType table,
-    srp_request.ship is None. In this case, we have to re-add the ship to prevent
-    errors in our DataTables ...
-
-    :param srp_request:
-    :type srp_request:
-    :return:
-    :rtype:
-    """
-
-    srp_kill_link_id = SrpManager.get_kill_id(killboard_link=srp_request.killboard_link)
-
-    (
-        ship_type_id,
-        ship_value,  # pylint: disable=unused-variable
-        victim_id,  # pylint: disable=unused-variable
-    ) = SrpManager.get_kill_data(kill_id=srp_kill_link_id)
-    (
-        srp_request__ship,
-        created_from_esi,  # pylint: disable=unused-variable
-    ) = EveType.objects.get_or_create_esi(id=ship_type_id)
-
-    srp_request.ship_name = srp_request__ship.name
-    srp_request.ship = srp_request__ship
-    srp_request.save()
-
-    return srp_request
-
-
-@login_required
 @permission_required("aasrp.basic_access")
 def dashboard_srp_links_data(
     request: WSGIRequest, show_all_links: bool = False
@@ -107,30 +81,24 @@ def dashboard_srp_links_data(
         srp_links = srp_links.filter(srp_status=SrpLink.Status.ACTIVE)
 
     for srp_link in srp_links:
-        aar_link = ""
-        if srp_link.aar_link:
-            aar_href = srp_link.aar_link
-            link_text = _("Link")
-            aar_link = f'<a href="{aar_href}" target="_blank">{link_text}</a>'
+        l10n_link = _("Link")
+        aar_link = (
+            f'<a href="{srp_link.aar_link}" target="_blank">{l10n_link}</a>'
+            if srp_link.aar_link
+            else ""
+        )
 
         srp_code_html = srp_link.srp_code
+
         if srp_link.srp_status == SrpLink.Status.ACTIVE:
-            css_classes = "aa-srp-fa-icon copy-text-fa-icon fa-regular fa-copy ms-2"
             srp_link_href = reverse_absolute(
                 viewname="aasrp:request_srp", args=[srp_link.srp_code]
             )
             title = _("Copy SRP link to clipboard")
-            srp_code_html += (
-                f'<i class="{css_classes}" '
-                f'data-clipboard-text="{srp_link_href}" title="{title}" '
-                'data-bs-tooltip="aa-srp"></i>'
-            )
+            copy_icon = copy_to_clipboard_icon(data=srp_link_href, title=title)
+            srp_code_html += f"<sup>{copy_icon}</sup>"
 
-        actions = get_dashboard_action_icons(request=request, srp_link=srp_link)
-
-        fleet_type = ""
-        if srp_link.fleet_type:
-            fleet_type = srp_link.fleet_type.name
+        fleet_type = srp_link.fleet_type.name if srp_link.fleet_type else ""
 
         data.append(
             {
@@ -138,21 +106,23 @@ def dashboard_srp_links_data(
                 "creator": get_main_character_name_from_user(user=srp_link.creator),
                 "fleet_time": srp_link.fleet_time,
                 "fleet_type": fleet_type,
-                # "fleet_commander": srp_link.fleet_commander.character_name,
                 "fleet_doctrine": srp_link.fleet_doctrine,
                 "aar_link": aar_link,
                 "srp_code": {"display": srp_code_html, "sort": srp_link.srp_code},
                 "srp_costs": srp_link.total_cost,
+                "srp_costs_html": {
+                    "display": localized_isk_value(srp_link.total_cost),
+                    "sort": srp_link.total_cost,
+                },
                 "srp_status": srp_link.srp_status,
                 "pending_requests": srp_link.pending_requests,
-                "actions": actions,
+                "actions": dashboard_action_icons(request=request, srp_link=srp_link),
             }
         )
 
     return JsonResponse(data=data, safe=False)
 
 
-@login_required
 @permission_required("aasrp.basic_access")
 def dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
     """
@@ -193,8 +163,8 @@ def dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
                 )
             except AttributeError:
                 # For some reason, it seems the ship has been removed from EveType
-                # table, attempt to add it again ...
-                srp_request = _attempt_to_re_add_ship_information_to_request(
+                # table, attempt to add it again …
+                srp_request = attempt_to_re_add_ship_information_to_request(
                     srp_request=srp_request
                 )
 
@@ -230,22 +200,32 @@ def dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
         data.append(
             {
                 "request_time": srp_request.post_time,
+                "character": srp_request.character.character_name,
                 "character_html": {
                     "display": character_display,
                     "sort": character_sort,
                 },
-                "character": srp_request.character.character_name,
-                "fleet_name": srp_request.srp_link.srp_name,
+                "fleet_name_html": {
+                    "display": request_fleet_details_html(srp_request=srp_request),
+                    "sort": srp_request.srp_link.srp_name,
+                },
                 "srp_code": srp_request.srp_link.srp_code,
                 "request_code": srp_request.request_code,
+                "ship": srp_request.ship.name,
                 "ship_html": {
                     "display": killboard_link,
                     "sort": srp_request.ship.name,
                 },
-                "ship": srp_request.ship.name,
                 "zkb_link": killboard_link,
-                "zbk_loss_amount": srp_request.loss_amount,
+                "zkb_loss_amount_html": {
+                    "display": localized_isk_value(srp_request.loss_amount),
+                    "sort": srp_request.loss_amount,
+                },
                 "payout_amount": srp_request.payout_amount,
+                "payout_amount_html": {
+                    "display": localized_isk_value(srp_request.payout_amount),
+                    "sort": srp_request.loss_amount,
+                },
                 "request_status_icon": (
                     srp_request_details_icon + srp_request_status_icon
                 ),
@@ -256,7 +236,6 @@ def dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
     return JsonResponse(data=data, safe=False)
 
 
-@login_required
 @permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
 def srp_link_view_requests_data(request: WSGIRequest, srp_code: str) -> JsonResponse:
     """
@@ -284,6 +263,7 @@ def srp_link_view_requests_data(request: WSGIRequest, srp_code: str) -> JsonResp
 
     for srp_request in srp_requests:
         killboard_link = ""
+
         if srp_request.killboard_link:
             try:
                 ship_render_icon_html = get_type_render_url_from_type_id(
@@ -294,10 +274,8 @@ def srp_link_view_requests_data(request: WSGIRequest, srp_code: str) -> JsonResp
                 )
             except AttributeError:
                 # For some reason, it seems the ship has been removed from EveType
-                # table, attempt to add it again ...
-                srp_request = _attempt_to_re_add_ship_information_to_request(
-                    srp_request
-                )
+                # table, attempt to add it again …
+                srp_request = attempt_to_re_add_ship_information_to_request(srp_request)
 
                 ship_render_icon_html = get_type_render_url_from_type_id(
                     evetype_id=srp_request.ship_id,
@@ -312,44 +290,56 @@ def srp_link_view_requests_data(request: WSGIRequest, srp_code: str) -> JsonResp
                 f"<span>{srp_request.ship.name}</span></a>"
             )
 
-        srp_request_status_icon = get_srp_request_status_icon(
-            request=request, srp_request=srp_request
-        )
-        srp_request_action_icons = get_srp_request_action_icons(
-            request=request, srp_link=srp_request.srp_link, srp_request=srp_request
-        )
-        character_display = get_formatted_character_name(
-            character=srp_request.character, with_portrait=True, with_copy_icon=True
-        )
-        character_sort = get_formatted_character_name(character=srp_request.character)
-
         data.append(
             {
                 "request_time": srp_request.post_time,
                 "requester": get_main_character_name_from_user(srp_request.creator),
                 "character_html": {
-                    "display": character_display,
-                    "sort": character_sort,
+                    "display": get_formatted_character_name(
+                        character=srp_request.character,
+                        with_portrait=True,
+                        with_copy_icon=True,
+                    ),
+                    "sort": srp_request.character.character_name,
                 },
                 "character": srp_request.character.character_name,
+                "request_code_html": {
+                    "display": request_code_html(request_code=srp_request.request_code),
+                    "sort": srp_request.request_code,
+                },
                 "request_code": srp_request.request_code,
                 "srp_code": srp_request.srp_link.srp_code,
                 "ship_html": {"display": killboard_link, "sort": srp_request.ship.name},
                 "ship": srp_request.ship.name,
                 "zkb_link": killboard_link,
+                "zkb_loss_amount_html": {
+                    "display": localized_isk_value(srp_request.loss_amount),
+                    "sort": srp_request.loss_amount,
+                },
                 "zbk_loss_amount": srp_request.loss_amount,
+                "payout_amount_html": {
+                    "display": payout_amount_html(
+                        payout_amount=srp_request.payout_amount
+                    ),
+                    "sort": srp_request.payout_amount,
+                },
                 "payout_amount": srp_request.payout_amount,
-                "request_status_icon": srp_request_status_icon,
-                "actions": srp_request_action_icons,
+                "request_status_icon": get_srp_request_status_icon(
+                    request=request, srp_request=srp_request
+                ),
+                "actions": get_srp_request_action_icons(
+                    request=request,
+                    srp_link=srp_request.srp_link,
+                    srp_request=srp_request,
+                ),
                 "request_status_translated": srp_request.get_request_status_display(),
                 "request_status": srp_request.request_status,
             }
         )
 
-    return JsonResponse(data, safe=False)
+    return JsonResponse(data=data, safe=False)
 
 
-@login_required
 @permission_required("aasrp.basic_access")
 def srp_request_additional_information(
     request: WSGIRequest, srp_code: str, srp_request_code: str
@@ -374,53 +364,44 @@ def srp_request_additional_information(
     insurance_information = srp_request.insurance.filter(srp_request=srp_request)
 
     character = get_formatted_character_name(
-        character=srp_request.character, with_portrait=True
+        character=srp_request.character, with_portrait=True, portrait_size=64
     )
 
     try:
         ship_render_icon_html = get_type_render_url_from_type_id(
             evetype_id=srp_request.ship_id,
             evetype_name=srp_request.ship.name,
-            size=32,
+            size=64,
             as_html=True,
         )
     except AttributeError:
         # For some reason, it seems the ship has been removed from EveType
-        # table, attempt to add it again ...
-        srp_request = _attempt_to_re_add_ship_information_to_request(
+        # table, attempt to add it again …
+        srp_request = attempt_to_re_add_ship_information_to_request(
             srp_request=srp_request
         )
 
         ship_render_icon_html = get_type_render_url_from_type_id(
             evetype_id=srp_request.ship_id,
             evetype_name=srp_request.ship.name,
-            size=32,
+            size=64,
             as_html=True,
         )
 
-    request_status_banner_alert_level = "info"
-    if srp_request.request_status == SrpRequest.Status.APPROVED:
-        request_status_banner_alert_level = "success"
+    request_status_banner_alert_level = {
+        SrpRequest.Status.APPROVED: "success",
+        SrpRequest.Status.REJECTED: "danger",
+    }.get(srp_request.request_status, "info")
 
-    if srp_request.request_status == SrpRequest.Status.REJECTED:
-        request_status_banner_alert_level = "danger"
+    additional_info = RequestComment.objects.filter(
+        srp_request=srp_request, comment_type=RequestComment.Type.REQUEST_INFO
+    ).first()
+    additional_info = additional_info.comment if additional_info else ""
 
-    try:
-        additional_info_comment = RequestComment.objects.get(
-            srp_request=srp_request, comment_type=RequestComment.Type.REQUEST_INFO
-        )
-
-        additional_info = additional_info_comment.comment
-    except RequestComment.DoesNotExist:
-        additional_info = ""
-
-    try:
-        request_history = RequestComment.objects.filter(
-            ~Q(comment_type=RequestComment.Type.REQUEST_INFO),
-            srp_request=srp_request,
-        ).order_by("pk")
-    except RequestComment.DoesNotExist:
-        request_history = ""
+    request_history = RequestComment.objects.filter(
+        ~Q(comment_type=RequestComment.Type.REQUEST_INFO),
+        srp_request=srp_request,
+    ).order_by("pk")
 
     data = {
         "srp_request": srp_request,
@@ -442,7 +423,6 @@ def srp_request_additional_information(
     )
 
 
-@login_required
 @permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
 def srp_request_change_payout(
     request: WSGIRequest, srp_code: str, srp_request_code: str
@@ -460,32 +440,24 @@ def srp_request_change_payout(
     :rtype:
     """
 
-    data = []
-
     if request.method == "POST":
         try:
             srp_request = SrpRequest.objects.get(
                 request_code=srp_request_code, srp_link__srp_code=srp_code
             )
-        except SrpRequest.DoesNotExist:
-            data.append({"success": False})
-        else:
-            # check whether it's valid:
             form = SrpRequestPayoutForm(data=request.POST)
-            if form.is_valid():
-                srp_payout = form.cleaned_data["value"]
 
-                srp_request.payout_amount = srp_payout
+            if form.is_valid():
+                srp_request.payout_amount = form.cleaned_data["value"]
                 srp_request.save()
 
-                data.append({"success": True})
-            else:
-                data.append({"success": False})
+                return JsonResponse(data={"success": True}, safe=False)
+        except SrpRequest.DoesNotExist:
+            pass
 
-    return JsonResponse(data=data, safe=False)
+    return JsonResponse(data={"success": False}, safe=False)
 
 
-@login_required
 @permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
 def srp_request_approve(  # pylint: disable=too-many-locals
     request: WSGIRequest, srp_code: str, srp_request_code: str
@@ -503,95 +475,178 @@ def srp_request_approve(  # pylint: disable=too-many-locals
     :rtype:
     """
 
-    data = []
-
     try:
         srp_request = SrpRequest.objects.get(
             request_code=srp_request_code, srp_link__srp_code=srp_code
         )
     except SrpRequest.DoesNotExist:
-        data.append({"success": False})
-    else:
-        if request.method == "POST":
-            # Create a form instance and populate it with data from the request
-            form = None
+        return JsonResponse(
+            data={"success": False, "message": _("No matching SRP request found")},
+            safe=False,
+        )
 
-            if srp_request.request_status == SrpRequest.Status.PENDING:
-                form = SrpRequestAcceptForm(data=request.POST)
-            elif srp_request.request_status == SrpRequest.Status.REJECTED:
-                form = SrpRequestAcceptRejectedForm(data=request.POST)
+    if request.method == "POST":
+        form = (
+            SrpRequestAcceptForm(data=json.loads(request.body))
+            if srp_request.request_status == SrpRequest.Status.PENDING
+            else (
+                SrpRequestAcceptRejectedForm(data=json.loads(request.body))
+                if srp_request.request_status == SrpRequest.Status.REJECTED
+                else None
+            )
+        )
 
-            if form and form.is_valid():
-                requester = srp_request.creator
-                srp_payout = srp_request.payout_amount
-                srp_isk_loss = srp_request.loss_amount
+        if not form.is_valid():
+            return JsonResponse(
+                data={"success": False, "message": _("Invalid form data")}, safe=False
+            )
 
-                # Reviser comment
-                reviser_comment = form.cleaned_data["comment"]
+        requester = srp_request.creator
+        srp_request.payout_amount = srp_request.payout_amount or srp_request.loss_amount
 
-                if srp_payout == 0:
-                    srp_request.payout_amount = srp_isk_loss
+        # Create comments in bulk
+        comments = [
+            RequestComment(
+                srp_request=srp_request,
+                comment_type=RequestComment.Type.STATUS_CHANGE,
+                new_status=SrpRequest.Status.APPROVED,
+                creator=request.user,
+            )
+        ]
 
-                # Set new status in request history
+        reviser_comment = form.cleaned_data["comment"]
+
+        if reviser_comment:
+            comments.append(
                 RequestComment(
                     srp_request=srp_request,
-                    comment_type=RequestComment.Type.STATUS_CHANGE,
-                    new_status=SrpRequest.Status.APPROVED,
+                    comment=reviser_comment,
+                    comment_type=RequestComment.Type.REVISER_COMMENT,
                     creator=request.user,
-                ).save()
+                )
+            )
+        RequestComment.objects.bulk_create(comments)
 
-                # Save reviser comment
-                if reviser_comment != "":
-                    RequestComment(
-                        srp_request=srp_request,
-                        comment=reviser_comment,
-                        comment_type=RequestComment.Type.REVISER_COMMENT,
-                        creator=request.user,
-                    ).save()
+        srp_request.request_status = SrpRequest.Status.APPROVED
+        srp_request.save()
 
-                srp_request.request_status = SrpRequest.Status.APPROVED
-                srp_request.save()
+        # Send notification if enabled
+        if not get_user_settings(user=requester).disable_notifications:
+            logger.info(msg="Sending approval message to user")
 
-                requester_user_settings = get_user_settings(user=requester)
+            notify_requester(
+                requester=requester,
+                reviser=get_main_character_name_from_user(user=request.user),
+                srp_request=srp_request,
+                comment=reviser_comment,
+            )
 
-                # Check if the requester has notifications activated (it's by default)
-                if requester_user_settings.disable_notifications is False:
-                    ship_name = srp_request.ship.name
-                    fleet_name = srp_request.srp_link.srp_name
-                    srp_code = srp_request.srp_link.srp_code
-                    request_code = srp_request.request_code
-                    reviser = get_main_character_name_from_user(user=request.user)
-                    reviser_comment = (
-                        f"\nComment:\n{reviser_comment}\n"
-                        if reviser_comment != ""
-                        else ""
-                    )
-                    inquiry_note = SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE
-                    notification_message = (
-                        f"Your SRP request regarding your {ship_name} lost during "
-                        f"{fleet_name} has been approved.\n\n"
-                        f"Request Details:\nSRP Code: {srp_code}\n"
-                        f"Request Code: {request_code}\n"
-                        f"Reviser: {reviser}\n{reviser_comment}\n{inquiry_note}"
-                    )
+        return JsonResponse(
+            data={"success": True, "message": _("SRP request has been approved")},
+            safe=False,
+        )
 
-                    logger.info(msg="Sending approval message to user")
+    return JsonResponse(
+        data={"success": False, "message": _("Invalid request method")},
+        safe=False,
+    )
 
-                    send_user_notification(
-                        user=requester,
-                        level="success",
-                        title="SRP Request Approved",
-                        message=notification_message,
-                    )
 
-                data.append(
-                    {"success": True, "message": _("SRP request has been approved")}
+@permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
+def srp_requests_bulk_approve(request: WSGIRequest, srp_code: str) -> JsonResponse:
+    """
+    Ajax call :: Approve multiple SRP requests
+
+    :param request:
+    :type request:
+    :param srp_code:
+    :type srp_code:
+    :return:
+    :rtype:
+    """
+
+    if request.method == "POST":
+        request_body = json.loads(request.body)
+        srp_request_codes = request_body.get("srp_request_codes")
+
+        logger.debug(
+            "Bulk approving SRP requests for code: %s, with request codes: %s",
+            srp_code,
+            srp_request_codes,
+        )
+
+        if not srp_request_codes or not srp_code:
+            return JsonResponse(
+                data={"success": False, "message": _("Invalid form data")}, safe=False
+            )
+
+        srp_requests = SrpRequest.objects.filter(
+            Q(request_code__in=srp_request_codes)
+            & Q(srp_link__srp_code=srp_code)
+            & Q(request_status=SrpRequest.Status.PENDING)
+        )
+
+        logger.debug(
+            "Found %d SRP requests to approve for code: %s",
+            srp_requests.count(),
+            srp_code,
+        )
+
+        if not srp_requests.exists():
+            return JsonResponse(
+                data={"success": False, "message": _("No matching SRP requests found")},
+                safe=False,
+            )
+
+        # Prepare bulk updates
+        srp_request_list = list(srp_requests)
+        for srp_request in srp_request_list:
+            srp_request.payout_amount = (
+                srp_request.payout_amount or srp_request.loss_amount
+            )
+            srp_request.request_status = SrpRequest.Status.APPROVED
+
+        # Bulk update all requests
+        SrpRequest.objects.bulk_update(
+            srp_request_list, ["payout_amount", "request_status"]
+        )
+
+        # Bulk create comments
+        comments = [
+            RequestComment(
+                srp_request=srp_request,
+                comment_type=RequestComment.Type.STATUS_CHANGE,
+                new_status=SrpRequest.Status.APPROVED,
+                creator=request.user,
+            )
+            for srp_request in srp_request_list
+        ]
+        RequestComment.objects.bulk_create(comments)
+
+        # Send notifications
+        reviser_name = get_main_character_name_from_user(user=request.user)
+        for srp_request in srp_request_list:
+            requester = srp_request.creator
+            if not get_user_settings(user=requester).disable_notifications:
+                logger.info(msg="Sending approval message to user")
+                notify_requester(
+                    requester=requester,
+                    reviser=reviser_name,
+                    srp_request=srp_request,
+                    comment="",
                 )
 
-    return JsonResponse(data=data, safe=False)
+        return JsonResponse(
+            data={"success": True, "message": _("SRP requests have been approved")},
+            safe=False,
+        )
+
+    return JsonResponse(
+        data={"success": False, "message": _("Invalid request method")},
+        safe=False,
+    )
 
 
-@login_required
 @permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
 def srp_request_deny(
     request: WSGIRequest, srp_code: str, srp_request_code: str
@@ -609,80 +664,70 @@ def srp_request_deny(
     :rtype:
     """
 
-    data = []
-
     try:
         srp_request = SrpRequest.objects.get(
             request_code=srp_request_code, srp_link__srp_code=srp_code
         )
     except SrpRequest.DoesNotExist:
-        data.append({"success": False})
-    else:
-        if request.method == "POST":
-            # Create a form instance and populate it with data from the request
-            form = SrpRequestRejectForm(data=request.POST)
+        return JsonResponse(
+            data={"success": False, "message": _("No matching SRP request found")},
+            safe=False,
+        )
 
-            # Check whether it's valid:
-            if form.is_valid():
-                reject_info = form.cleaned_data["comment"]
-                requester = srp_request.creator
+    if request.method == "POST":
+        form = SrpRequestRejectForm(data=json.loads(request.body))
 
-                srp_request.payout_amount = 0
-                srp_request.request_status = SrpRequest.Status.REJECTED
-                srp_request.save()
+        if not form.is_valid():
+            return JsonResponse(
+                data={"success": False, "message": _("Invalid form data")}, safe=False
+            )
 
-                # Set new status in request history
+        reject_info = form.cleaned_data["comment"]
+        requester = srp_request.creator
+
+        srp_request.payout_amount = 0
+        srp_request.request_status = SrpRequest.Status.REJECTED
+        srp_request.save()
+
+        RequestComment.objects.bulk_create(
+            [
                 RequestComment(
                     srp_request=srp_request,
                     comment_type=RequestComment.Type.STATUS_CHANGE,
                     new_status=SrpRequest.Status.REJECTED,
                     creator=request.user,
-                ).save()
-
-                # Save reject reason as comment for this request
+                ),
                 RequestComment(
                     comment=reject_info,
                     srp_request=srp_request,
                     comment_type=RequestComment.Type.REJECT_REASON,
                     creator=request.user,
-                ).save()
+                ),
+            ]
+        )
 
-                requester_user_settings = get_user_settings(user=requester)
+        if not get_user_settings(user=requester).disable_notifications:
+            logger.info("Sending reject message to user")
 
-                # Check if the requester has notifications activated (it's by default)
-                if requester_user_settings.disable_notifications is False:
-                    ship_name = srp_request.ship.name
-                    fleet_name = srp_request.srp_link.srp_name
-                    srp_code = srp_request.srp_link.srp_code
-                    request_code = srp_request.request_code
-                    reviser = get_main_character_name_from_user(user=request.user)
-                    inquiry_note = SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE
-                    notification_message = (
-                        f"Your SRP request regarding your {ship_name} lost during "
-                        f"{fleet_name} has been rejected.\n\n"
-                        f"Reason:\n{reject_info}\n\n"
-                        f"Request Details:\nSRP Code: {srp_code}\n"
-                        f"Request Code: {request_code}\n"
-                        f"Reviser: {reviser}\n\n{inquiry_note}"
-                    )
+            notify_requester(
+                requester=requester,
+                reviser=get_main_character_name_from_user(user=request.user),
+                srp_request=srp_request,
+                comment=reject_info,
+                message_level="danger",
+            )
 
-                    logger.info(msg="Sending reject message to user")
+        return JsonResponse(
+            data={"success": True, "message": _("SRP request has been rejected")},
+            safe=False,
+        )
 
-                    send_user_notification(
-                        user=requester,
-                        level="danger",
-                        title=_("SRP request rejected"),
-                        message=notification_message,
-                    )
-
-                data.append(
-                    {"success": True, "message": _("SRP request has been rejected")}
-                )
-
-    return JsonResponse(data=data, safe=False)
+    return JsonResponse(
+        data={"success": False, "message": _("Invalid request method")},
+        safe=False,
+    )
 
 
-@login_required
 @permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
 def srp_request_remove(
     request: WSGIRequest,  # pylint: disable=unused-argument
@@ -702,17 +747,70 @@ def srp_request_remove(
     :rtype:
     """
 
-    data = []
-
     try:
-        srp_request = SrpRequest.objects.get(
+        SrpRequest.objects.get(
             request_code=srp_request_code, srp_link__srp_code=srp_code
-        )
-    except SrpRequest.DoesNotExist:
-        data.append({"success": False})
-    else:
-        srp_request.delete()
+        ).delete()
 
-        data.append({"success": True, "message": _("SRP request has been removed")})
+        data = {"success": True, "message": _("SRP request has been removed")}
+    except SrpRequest.DoesNotExist:
+        data = {"success": False, "message": _("No matching SRP request found")}
 
     return JsonResponse(data=data, safe=False)
+
+
+@permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
+def srp_requests_bulk_remove(request: WSGIRequest, srp_code: str) -> JsonResponse:
+    """
+    Ajax call :: Remove multiple SRP requests
+
+    :param request:
+    :type request:
+    :param srp_code:
+    :type srp_code:
+    :return:
+    :rtype:
+    """
+
+    if request.method == "POST":
+        request_body = json.loads(request.body)
+        srp_request_codes = request_body.get("srp_request_codes")
+
+        logger.debug(
+            "Bulk removing SRP requests for code: %s, with request codes: %s",
+            srp_code,
+            srp_request_codes,
+        )
+
+        if not srp_request_codes or not srp_code:
+            return JsonResponse(
+                data={"success": False, "message": _("Invalid form data")}, safe=False
+            )
+
+        srp_requests = SrpRequest.objects.filter(
+            Q(request_code__in=srp_request_codes) & Q(srp_link__srp_code=srp_code)
+        )
+
+        logger.debug(
+            "Found %d SRP requests to remove for code: %s",
+            srp_requests.count(),
+            srp_code,
+        )
+
+        if not srp_requests.exists():
+            return JsonResponse(
+                data={"success": False, "message": _("No matching SRP requests found")},
+                safe=False,
+            )
+
+        srp_requests.delete()
+
+        return JsonResponse(
+            data={"success": True, "message": _("SRP requests have been removed")},
+            safe=False,
+        )
+
+    return JsonResponse(
+        data={"success": False, "message": _("Invalid request method")},
+        safe=False,
+    )
